@@ -23,7 +23,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c 1442 2007-01-28 20:17:38Z jframeau $
+ *  $Id: page-info-dialog.c 1672 2008-02-18 19:08:12Z cosimoc $
  */
 
 #include "config.h"
@@ -59,14 +59,11 @@
 #include <gtk/gtkclipboard.h>
 #include <gtk/gtkmain.h>
 
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
-
 #include "mozilla/mozilla-helpers.h"
 
 #include <glib/gi18n-lib.h>
 #include <glib/gconvert.h>
+#include <gio/gio.h>
 
 #include <time.h>
 #include <string.h>
@@ -76,8 +73,8 @@
 
 /* Forward declarations */
 static void page_info_set_text (PageInfoDialog *dialog,
-		    		const char *prop,
-		    		const char *text);
+				const char *prop,
+				const char *text);
 
 enum {
 	GENERAL_PAGE,
@@ -160,7 +157,7 @@ enum
 	PROP_META_DC_FORMAT,
 	PROP_META_OTHER_LABEL,
 	PROP_META_TREEVIEW,
-	
+
 /*
 	PROP_SECURITY_CERT_TITLE,
 	PROP_SECURITY_CERT_INFO,
@@ -235,7 +232,7 @@ page_info_dialog_get_type (void)
 	return type;
 }
 
-GType 
+GType
 page_info_dialog_register_type (GTypeModule *module)
 {
 	const GTypeInfo our_info =
@@ -288,7 +285,7 @@ setup_page_security (PageInfoDialog *dialog, EmbedPageProperties *props)
 */
 	/* Web Site Identity Verification */
 /*
-	widget = galeon_dialog_get_control (GALEON_DIALOG (dialog), 
+	widget = galeon_dialog_get_control (GALEON_DIALOG (dialog),
 					    PROP_SECURITY_VIEW_CERT_VBOX);
 	if (!props->secret_key_length)
 	{
@@ -359,7 +356,7 @@ setup_page_security (PageInfoDialog *dialog, EmbedPageProperties *props)
 		{
 			msg1 = g_strdup (_("The page you are viewing is not encrypted."));
 		}
-				
+
 
 		msg2 = _("Information sent over the Internet without encryption "
 			 "can be seen by other people while it is in transit.");
@@ -386,7 +383,7 @@ page_info_dialog_set_current_page (PageInfoDialog *dialog, PageInfoDialogPage pa
 {
 	GtkNotebook *notebook;
 	guint        n_pages;
-	
+
 	notebook = GTK_NOTEBOOK(dialog->priv->notebook);
 	n_pages  = gtk_notebook_get_n_pages(notebook);
 
@@ -423,23 +420,23 @@ page_info_set_text (PageInfoDialog *dialog,
 	gtk_label_set_text (GTK_LABEL (widget), text ? text : "");
 }
 
-/* 
-   Asks to a renderer to ellipsize urls 
-   and set the maximum size of the rendered urls 
+/*
+   Asks to a renderer to ellipsize urls
+   and set the maximum size of the rendered urls
 */
 static void
 page_info_set_url_renderer_props (GtkCellRenderer *renderer)
 {
-	g_object_set (G_OBJECT (renderer), 
+	g_object_set (G_OBJECT (renderer),
 		      "ellipsize", PANGO_ELLIPSIZE_MIDDLE, NULL);
-	g_object_set (G_OBJECT (renderer), 
+	g_object_set (G_OBJECT (renderer),
 		      "width-chars", PAGE_INFO_MAX_URL_LENGTH, NULL);
 }
 
 /* Set dnd cursor to the default dnd Gtk one and not the GtktreeView one */
-static void 
-page_info_drag_begin_cb (GtkWidget *widget, 
-		         GdkDragContext *dc, 
+static void
+page_info_drag_begin_cb (GtkWidget *widget,
+		         GdkDragContext *dc,
 		         gpointer user_data)
 {
 	gtk_drag_set_icon_default (dc);
@@ -522,14 +519,14 @@ treeview_info_page_copy_selected (GtkAction *action,
 
 	data = treeview_info_page_get_selected_data (page);
 	if (data == NULL) return;
-		
+
 	gtk_clipboard_set_text (gtk_clipboard_get (GDK_NONE),
 				data, -1);
 	gtk_clipboard_set_text (gtk_clipboard_get (GDK_SELECTION_PRIMARY),
 				data, -1);
 
 	g_free (data);
-}				  
+}
 
 static void
 treeview_info_page_filter (TreeviewInfoPage *page)
@@ -581,7 +578,7 @@ treeview_info_page_button_pressed_cb (GtkTreeView *treeview,
 	/* right-click? */
 	if (event->button != 3)
 	{
-	       return FALSE;
+		return FALSE;
 	}
 
 	/* Get tree path for row that was clicked */
@@ -589,13 +586,13 @@ treeview_info_page_button_pressed_cb (GtkTreeView *treeview,
 					    event->x, event->y,
 					    &path, NULL, NULL, NULL))
 	{
-	       return FALSE;
+		return FALSE;
 	}
 
 	if (!gtk_tree_model_get_iter (model, &iter, path))
 	{
-	       gtk_tree_path_free(path);
-	       return FALSE;
+		gtk_tree_path_free(path);
+		return FALSE;
 	}
 
 	/* Select the row the user clicked on */
@@ -607,11 +604,11 @@ treeview_info_page_button_pressed_cb (GtkTreeView *treeview,
 		gtk_tree_path_free (path);
 	}
 
-        if (page->filter_func)
-        {
+	if (page->filter_func)
+	{
 		page->filter_func (page);
-        }
-       
+	}
+
 	/* now popup the menu */
 	widget = gtk_ui_manager_get_widget (dialog->priv->manager,
 					    page->popup_path);
@@ -632,10 +629,10 @@ treeview_info_page_construct (InfoPage *ipage)
 				      page->n_action_entries,
 				      page);
 
-	g_signal_connect (page->treeview, "button-press-event", 
-			  G_CALLBACK (treeview_info_page_button_pressed_cb), 
+	g_signal_connect (page->treeview, "button-press-event",
+			  G_CALLBACK (treeview_info_page_button_pressed_cb),
 			  page);
-	g_signal_connect_swapped (page->treeview, "popup-menu", 
+	g_signal_connect_swapped (page->treeview, "popup-menu",
 				  G_CALLBACK (treeview_info_page_show_popup),
 				  page);
 }
@@ -645,35 +642,30 @@ static void
 treeview_page_info_save_one_selection (const char *source,
 	                               const char *dir)
 {
-	GnomeVFSURI *uri;
+	GFile *file;
 	EphyEmbedPersist *persist;
+	char *file_name;
 
-	uri = gnome_vfs_uri_new (source);
-	if (uri != NULL)
-	{	
-		char *file_name;
-
-		file_name = gnome_vfs_uri_extract_short_name (uri);
-		if (file_name != NULL)
-		{
-			char *dest;
+	file = g_file_new_for_uri (source);
 
+	file_name = g_file_get_basename (file);
+	if (file_name != NULL)
+	{
+		char *dest;
 			/* Persist needs a full path */
-			dest = g_build_filename (dir, file_name, NULL);
+		dest = g_build_filename (dir, file_name, NULL);
 
-			persist = EPHY_EMBED_PERSIST (
-					ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
-			ephy_embed_persist_set_source (persist, source);
-			ephy_embed_persist_set_dest (persist, dest);
-			ephy_embed_persist_save (persist);
+		persist = EPHY_EMBED_PERSIST (ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
+		ephy_embed_persist_set_source (persist, source);
+		ephy_embed_persist_set_dest (persist, dest);
+		ephy_embed_persist_save (persist);
 
-			g_object_unref (persist);
-			g_free(dest);
-		}
-
-		g_free (file_name);
-		gnome_vfs_uri_unref (uri);
+		g_object_unref (persist);
+		g_free(dest);
 	}
+
+	g_free (file_name);
+	g_object_unref (file);
 }
 
 /* Download at the same time all the selelected links (rows) */
@@ -745,9 +737,9 @@ treeview_page_info_save_selected_cb (gpointer ptr,
 		parent = NULL;
 
 		fc = ephy_file_chooser_new (_("Select a directory"),
-				            GTK_WIDGET (parent),
-				            GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-				            NULL, EPHY_FILE_FILTER_NONE);
+					    GTK_WIDGET (parent),
+					    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+					    NULL, EPHY_FILE_FILTER_NONE);
 
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fc),
 						     g_get_home_dir ());
@@ -773,6 +765,7 @@ general_info_page_fill (InfoPage *page)
 	const char *date_hack = "%c"; /* quiet gcc */
 	char date[128];
 	char *val;
+	const char *title;
 	struct tm tm;
 	time_t t;
 
@@ -781,9 +774,8 @@ general_info_page_fill (InfoPage *page)
 	props = dialog->priv->page_info->props;
 	g_return_if_fail (props != NULL);
 
-	val = ephy_embed_get_title (embed);
-	page_info_set_text (dialog, properties[PROP_GENERAL_PAGE_TITLE].id, val);
-	g_free (val);
+	title = ephy_embed_get_title (embed);
+	page_info_set_text (dialog, properties[PROP_GENERAL_PAGE_TITLE].id, title);
 
 	val = ephy_embed_get_location (embed, TRUE);
 	page_info_set_text (dialog, properties[PROP_GENERAL_URL].id, val);
@@ -791,7 +783,7 @@ general_info_page_fill (InfoPage *page)
 
 	page_info_set_text (dialog, properties[PROP_GENERAL_MIME_TYPE].id, props->content_type);
 
-	text = gnome_vfs_mime_get_description (props->content_type);
+	text = g_content_type_get_description (props->content_type);
 	page_info_set_text (dialog, properties[PROP_GENERAL_TYPE].id,
 			    text ? text : _("Unknown type"));
 
@@ -822,7 +814,7 @@ general_info_page_fill (InfoPage *page)
 		case EMBED_SOURCE_DISK_CACHE:
 			text = _("Disk cache");
 			break;
-		case EMBED_SOURCE_MEMORY_CACHE:	
+		case EMBED_SOURCE_MEMORY_CACHE:
 			text = _("Memory cache");
 			break;
 		case EMBED_SOURCE_UNKNOWN_CACHE:
@@ -834,9 +826,9 @@ general_info_page_fill (InfoPage *page)
 
 	page_info_set_text (dialog, properties[PROP_GENERAL_ENCODING].id, props->encoding);
 
-	if (props->size != -1) 
+	if (props->size != -1)
 	{
-		val = gnome_vfs_format_file_size_for_display (props->size);
+		val = g_format_size_for_display ((goffset) props->size);
 		page_info_set_text (dialog, properties[PROP_GENERAL_SIZE].id, val);
 		g_free (val);
 	}
@@ -848,13 +840,13 @@ general_info_page_fill (InfoPage *page)
 	page_info_set_text (dialog, properties[PROP_GENERAL_REFERRING_URL].id,
 			    props->referring_url ? props->referring_url :
 			    _("No referrer"));
-	
+
 	if (props->modification_time)
 	{
 		t = props->modification_time;
 		strftime (date, sizeof (date), date_hack, localtime_r (&t, &tm));
 		val = g_locale_to_utf8 (date, -1, NULL, NULL, NULL);
-		
+
 		page_info_set_text (dialog, properties[PROP_GENERAL_MODIFIED].id, val);
 		g_free (val);
 	}
@@ -939,10 +931,10 @@ mozilla_embed_type_to_string (EmbedPageMediumType type)
 
 	switch (type)
 	{
-		case MEDIUM_IMAGE: 
+		case MEDIUM_IMAGE:
 			s_type = _("Image");
 			break;
-		case MEDIUM_BG_IMAGE: 
+		case MEDIUM_BG_IMAGE:
 			s_type = _("Background image");
 			break;
 		case MEDIUM_EMBED:
@@ -966,18 +958,20 @@ mozilla_embed_type_to_string (EmbedPageMediumType type)
 
 static gboolean
 media_is_medium_blocked (EphyAdBlockManager *manager,
-		         const char *url,
+			 EphyEmbed *embed,
+			 const char *url,
 			 EmbedPageMediumType type)
 {
 	gboolean should_load;
 
 	switch (type)
 	{
-		case MEDIUM_IMAGE: 
+		case MEDIUM_IMAGE:
 		case MEDIUM_ICON:
 			should_load = ephy_adblock_manager_should_load (
-							manager, 
-					 		url, 
+							manager,
+							embed,
+							url,
 							AD_URI_CHECK_TYPE_IMAGE);
 
 			break;
@@ -985,24 +979,28 @@ media_is_medium_blocked (EphyAdBlockManager *manager,
 		case MEDIUM_OBJECT:
 		case MEDIUM_APPLET:
 			should_load = ephy_adblock_manager_should_load (
-							manager, 
-					 		url, 
+							manager,
+							embed,
+							url,
 							AD_URI_CHECK_TYPE_OBJECT);
 
 			break;
 		default:
 			should_load = ephy_adblock_manager_should_load (
-							manager, 
-					 		url, 
+							manager,
+							embed,
+							url,
 							AD_URI_CHECK_TYPE_OTHER);
 	}
 	return should_load;
 }
 
 static void
-media_sync_adblock (EphyAdBlockManager *manager, 
+media_sync_adblock (EphyAdBlockManager *manager,
 		    TreeviewInfoPage *page)
 {
+	PageInfoDialog *dialog = page->page.dialog;
+	EphyEmbed *embed = dialog->priv->embed;
 	GtkTreeIter   iter;
 	gboolean      iter_valid;
 	GtkTreeModel *model = GTK_TREE_MODEL (page->store);
@@ -1017,10 +1015,10 @@ media_sync_adblock (EphyAdBlockManager *manager,
 
 		gtk_tree_model_get (model, &iter, COL_MEDIUM_URL, &url, COL_MEDIUM_TYPE, &type, -1);
 
-		should_load = media_is_medium_blocked (manager, url, type);
+		should_load = media_is_medium_blocked (manager, embed, url, type);
 
 		gtk_list_store_set (page->store, &iter, COL_MEDIUM_BLOCKED, !should_load, -1);
-		
+
 		g_free (url);
 	}
 }
@@ -1058,11 +1056,14 @@ media_open_medium_cb (GtkAction *action,
 }
 
 static void
-background_download_completed_cb (EphyEmbedPersist *persist)
+background_download_completed_cb (EphyEmbedPersist *persist,
+				  GtkAction *action)
 {
 	const char *bg;
 	char *type;
 	guint32 user_time;
+	GtkWidget *proxy;
+	GSList *proxies;
 
 	user_time = ephy_embed_persist_get_user_time (persist);
 
@@ -1076,8 +1077,14 @@ background_download_completed_cb (EphyEmbedPersist *persist)
 	}
 	g_free (type);
 
-        /* open the "Background Properties" capplet */
-        ephy_file_launch_desktop_file ("background.desktop", user_time);
+	proxies = gtk_action_get_proxies (action);
+	proxy = GTK_WIDGET (proxies->data);
+
+	/* open the "Background Properties" capplet */
+	ephy_file_launch_desktop_file ("background.desktop",
+				       NULL,
+				       user_time,
+				       proxy);
 }
 
 static void
@@ -1106,7 +1113,7 @@ media_set_image_as_background_cb (GtkAction *action,
 	ephy_embed_persist_set_flags (persist, EPHY_EMBED_PERSIST_NO_VIEW);
 
 	g_signal_connect (persist, "completed",
-			  G_CALLBACK (background_download_completed_cb), NULL);
+			  G_CALLBACK (background_download_completed_cb), action);
 
 	ephy_embed_persist_save (persist);
 
@@ -1137,7 +1144,7 @@ static const GtkActionEntry media_action_entries[] =
 	  NULL,
 	  NULL,
 	  G_CALLBACK (media_set_image_as_background_cb) },
-	{ "SaveAs", 
+	{ "SaveAs",
 	  GTK_STOCK_SAVE_AS,
 	  N_("_Save As..."),
 	  NULL,
@@ -1170,12 +1177,12 @@ page_info_media_box_realize_cb (GtkContainer *box,
 	ephy_embed_load_url (embed, "about:blank");
 }
 
-static gboolean 
+static gboolean
 media_treeview_selection_changed_cb (GtkTreeSelection *selection,
-                                     GtkTreeModel *model,
-                                     GtkTreePath *path,
-                                     gboolean path_currently_selected,
-                                     MediaInfoPage *page)
+				     GtkTreeModel *model,
+				     GtkTreePath *path,
+				     gboolean path_currently_selected,
+				     MediaInfoPage *page)
 {
 	if (path_currently_selected) return TRUE;
 
@@ -1198,14 +1205,14 @@ media_treeview_selection_changed_cb (GtkTreeSelection *selection,
 		if (url != NULL && !media_is_embedded_medium (type))
 		{
 			/* Workaround for bad content type */
-			char *data = 
+			char *data =
 				g_markup_printf_escaped ("data:text/html,"
 							 "<html><body><img src="
-					     		 "%s></body></html>", url);
-							
+							 "%s></body></html>", url);
+
 			/* We ask explicitly to not download anything. */
-			g_object_set_data (G_OBJECT (page->embed), 
-					   "content-handler-deny", 
+			g_object_set_data (G_OBJECT (page->embed),
+					   "content-handler-deny",
 					   GINT_TO_POINTER (TRUE));
 
 			ephy_embed_load_url (page->embed, data);
@@ -1257,11 +1264,11 @@ media_info_page_filter (TreeviewInfoPage *page)
 
 static void
 media_drag_data_get_cb (GtkWidget *widget,
-                        GdkDragContext *context,
-                        GtkSelectionData *selection_data,
-                        guint info,
-                        guint32 time,
-                        MediaInfoPage *page)
+			GdkDragContext *context,
+			GtkSelectionData *selection_data,
+			guint info,
+			guint32 time,
+			MediaInfoPage *page)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) page;
 	char *address;
@@ -1278,15 +1285,15 @@ media_drag_data_get_cb (GtkWidget *widget,
 
 static void
 treeview_page_info_blocked_cb (GtkCellRendererToggle *cell_renderer,
-               		       gchar *path,
-               		       TreeviewInfoPage *tpage)
-{	
+			       gchar *path,
+			       TreeviewInfoPage *tpage)
+{
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 
 	model = GTK_TREE_MODEL (tpage->store);
 
-	if (gtk_tree_model_get_iter_from_string (model, &iter, path)) 
+	if (gtk_tree_model_get_iter_from_string (model, &iter, path))
 	{
 		char *url;
 		gboolean state;
@@ -1305,7 +1312,7 @@ treeview_page_info_blocked_cb (GtkCellRendererToggle *cell_renderer,
 		ephy_adblock_manager_edit_rule (adblock_manager, url, state);
 
 		g_free (url);
-	}	
+	}
 }
 
 static void
@@ -1349,18 +1356,18 @@ media_info_page_construct (InfoPage *ipage)
 
 	/* Allow the tree to be a source for dnd */
 	gtk_tree_view_enable_model_drag_source (treeview, GDK_BUTTON1_MASK,
-                                                drag_targets, G_N_ELEMENTS (drag_targets),
+						drag_targets, G_N_ELEMENTS (drag_targets),
                                                 GDK_ACTION_COPY);
 	g_signal_connect (G_OBJECT(treeview),
-                          "drag_data_get",
-                          G_CALLBACK(media_drag_data_get_cb),
-                          page);
+			  "drag_data_get",
+			  G_CALLBACK(media_drag_data_get_cb),
+			  page);
 
-	/* Be careful, default handler forces dnd icon to be an image of the row ! */ 
+	/* Be careful, default handler forces dnd icon to be an image of the row ! */
 	g_signal_connect_after (G_OBJECT(treeview),
-                                "drag_begin",
-                                G_CALLBACK(page_info_drag_begin_cb),
-                                NULL);
+				"drag_begin",
+				G_CALLBACK(page_info_drag_begin_cb),
+				NULL);
 
 	selection = gtk_tree_view_get_selection (treeview);
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
@@ -1378,13 +1385,13 @@ media_info_page_construct (InfoPage *ipage)
 	column = gtk_tree_view_get_column (treeview, COL_MEDIUM_BLOCKED);
 	gtk_tree_view_column_set_reorderable (column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, TV_COL_MEDIUM_BLOCKED);
-	gtk_tree_view_column_set_visible (column, 
+	gtk_tree_view_column_set_visible (column,
 					  ephy_adblock_manager_has_blocker (adblock_manager));
 	g_signal_connect (renderer, "toggled",
 			  G_CALLBACK (treeview_page_info_blocked_cb), tpage);
-	
+
 	renderer = gtk_cell_renderer_text_new ();
-	page_info_set_url_renderer_props (renderer); 
+	page_info_set_url_renderer_props (renderer);
 	gtk_tree_view_insert_column_with_attributes (treeview,
 						     TV_COL_MEDIUM_URL,
 						     _("URL"),
@@ -1411,7 +1418,7 @@ media_info_page_construct (InfoPage *ipage)
 	gtk_tree_view_column_set_sort_column_id (column, COL_MEDIUM_TYPE_TEXT);
 
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     TV_COL_MEDIUM_ALT, 
+						     TV_COL_MEDIUM_ALT,
 						     _("Alt Text"),
 						     renderer,
 						     "text", COL_MEDIUM_ALT,
@@ -1423,7 +1430,7 @@ media_info_page_construct (InfoPage *ipage)
 	gtk_tree_view_column_set_sort_column_id (column, COL_MEDIUM_ALT);
 
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     TV_COL_MEDIUM_TITLE, 
+						     TV_COL_MEDIUM_TITLE,
 						     _("Title"),
 						     renderer,
 						     "text", COL_MEDIUM_TITLE,
@@ -1435,7 +1442,7 @@ media_info_page_construct (InfoPage *ipage)
 	gtk_tree_view_column_set_sort_column_id (column, COL_MEDIUM_TITLE);
 
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     TV_COL_MEDIUM_WIDTH, 
+						     TV_COL_MEDIUM_WIDTH,
 						     _("Width"),
 						     renderer,
 						     "text", COL_MEDIUM_WIDTH,
@@ -1447,7 +1454,7 @@ media_info_page_construct (InfoPage *ipage)
 	gtk_tree_view_column_set_sort_column_id (column, COL_MEDIUM_WIDTH);
 
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     TV_COL_MEDIUM_HEIGHT, 
+						     TV_COL_MEDIUM_HEIGHT,
 						     _("Height"),
 						     renderer,
 						     "text", COL_MEDIUM_HEIGHT,
@@ -1487,9 +1494,10 @@ media_info_page_fill (InfoPage *ipage)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) ipage;
 	PageInfoDialog *dialog = ipage->dialog;
+	EphyEmbed *embed = dialog->priv->embed;
 	GtkListStore *store = tpage->store;
 	GtkTreeIter iter;
-	GList *media, *l;	
+	GList *media, *l;
 	EphyAdBlockManager *adblock_manager;
 	gboolean should_load;
 
@@ -1504,8 +1512,9 @@ media_info_page_fill (InfoPage *ipage)
 	{
 		EmbedPageMedium *media = (EmbedPageMedium *) l->data;
 
-		should_load = media_is_medium_blocked (adblock_manager, 
-						       media->url, 
+		should_load = media_is_medium_blocked (adblock_manager,
+						       embed,
+						       media->url,
 						       media->type);
 
 		gtk_list_store_append (store, &iter);
@@ -1522,8 +1531,8 @@ media_info_page_fill (InfoPage *ipage)
 	}
 	if (ephy_adblock_manager_has_blocker (adblock_manager))
 	{
-		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(store), 
-						      COL_MEDIUM_BLOCKED, 	
+		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(store),
+						      COL_MEDIUM_BLOCKED,
 						      GTK_SORT_DESCENDING);
 	}
 }
@@ -1568,13 +1577,13 @@ enum
 
 static const GtkActionEntry links_action_entries[] =
 {
-	{ "CopyLinkAddress", 
+	{ "CopyLinkAddress",
 	  GTK_STOCK_COPY,
 	  N_("_Copy Link Address"),
 	  NULL,
 	  NULL,
 	  G_CALLBACK (treeview_info_page_copy_selected) },
-	{ "LinkSaveAs", 
+	{ "LinkSaveAs",
 	  GTK_STOCK_SAVE_AS,
 	  N_("_Save As..."),
 	  NULL,
@@ -1584,11 +1593,11 @@ static const GtkActionEntry links_action_entries[] =
 
 static void
 links_drag_data_get_cb (GtkWidget *widget,
-                        GdkDragContext *context,
-                        GtkSelectionData *selection_data,
-                        guint info,
-                        guint32 time,
-                        LinksInfoPage *page)
+			GdkDragContext *context,
+			GtkSelectionData *selection_data,
+			guint info,
+			guint32 time,
+			LinksInfoPage *page)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) page;
 	char *address;
@@ -1607,17 +1616,21 @@ links_drag_data_get_cb (GtkWidget *widget,
 
 static gboolean
 links_is_link_blocked (EphyAdBlockManager *manager,
+		       EphyEmbed *embed,
 		       const char *url)
 {
-	return ephy_adblock_manager_should_load (manager, 
-						 url, 
+	return ephy_adblock_manager_should_load (manager,
+						 embed,
+						 url,
 						 AD_URI_CHECK_TYPE_OTHER);
 }
 
 static void
-links_sync_adblock (EphyAdBlockManager *manager, 
+links_sync_adblock (EphyAdBlockManager *manager,
 		    TreeviewInfoPage *page)
 {
+	PageInfoDialog *dialog = page->page.dialog;
+	EphyEmbed *embed = dialog->priv->embed;
 	GtkTreeIter   iter;
 	gboolean      iter_valid;
 	GtkTreeModel *model = GTK_TREE_MODEL (page->store);
@@ -1631,10 +1644,10 @@ links_sync_adblock (EphyAdBlockManager *manager,
 
 		gtk_tree_model_get (model, &iter, COL_LINK_URL, &url, -1);
 
-		should_load = links_is_link_blocked (manager, url);
+		should_load = links_is_link_blocked (manager, embed, url);
 
 		gtk_list_store_set (page->store, &iter, COL_LINK_BLOCKED, !should_load, -1);
-		
+
 		g_free (url);
 	}
 }
@@ -1671,18 +1684,18 @@ links_info_page_construct (InfoPage *ipage)
 
 	/* Allow the tree to be a source for dnd */
 	gtk_tree_view_enable_model_drag_source (treeview, GDK_BUTTON1_MASK,
-                                                drag_targets, G_N_ELEMENTS (drag_targets),
-                                                GDK_ACTION_COPY);
+						drag_targets, G_N_ELEMENTS (drag_targets),
+						GDK_ACTION_COPY);
 	g_signal_connect (G_OBJECT(treeview),
-                          "drag_data_get",
-                          G_CALLBACK(links_drag_data_get_cb),
-                          ipage);
+			  "drag_data_get",
+			  G_CALLBACK(links_drag_data_get_cb),
+			  ipage);
 
-	/* Be careful, default handler forces dnd icon to be an image of the row ! */ 
+	/* Be careful, default handler forces dnd icon to be an image of the row ! */
 	g_signal_connect_after (G_OBJECT(treeview),
-                                "drag_begin",
-                                G_CALLBACK(page_info_drag_begin_cb),
-                                NULL);
+				"drag_begin",
+				G_CALLBACK(page_info_drag_begin_cb),
+				NULL);
 
 	renderer = gtk_cell_renderer_toggle_new ();
 	gtk_tree_view_insert_column_with_attributes (treeview,
@@ -1691,7 +1704,7 @@ links_info_page_construct (InfoPage *ipage)
 						     "active", COL_LINK_BLOCKED,
 						     NULL);
 	column = gtk_tree_view_get_column (treeview, COL_LINK_BLOCKED);
-	gtk_tree_view_column_set_visible (column, 
+	gtk_tree_view_column_set_visible (column,
 					  ephy_adblock_manager_has_blocker (adblock_manager));
 	gtk_tree_view_column_set_reorderable (column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, COL_LINK_BLOCKED);
@@ -1699,7 +1712,7 @@ links_info_page_construct (InfoPage *ipage)
 			  G_CALLBACK (treeview_page_info_blocked_cb), tpage);
 
 	renderer = gtk_cell_renderer_text_new ();
-	page_info_set_url_renderer_props (renderer); 
+	page_info_set_url_renderer_props (renderer);
 	gtk_tree_view_insert_column_with_attributes (treeview,
 						     COL_LINK_URL,
 						     _("URL"),
@@ -1714,7 +1727,7 @@ links_info_page_construct (InfoPage *ipage)
 
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     COL_LINK_TITLE, 
+						     COL_LINK_TITLE,
 						     _("Title"),
 						     renderer,
 						     "text", COL_LINK_TITLE,
@@ -1726,7 +1739,7 @@ links_info_page_construct (InfoPage *ipage)
 	gtk_tree_view_column_set_sort_column_id (column, COL_LINK_TITLE);
 
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     COL_LINK_REL, 
+						     COL_LINK_REL,
 						     _("Relation"),
 						     renderer,
 						     "text", COL_LINK_REL,
@@ -1749,6 +1762,7 @@ links_info_page_fill (InfoPage *ipage)
 {
 	TreeviewInfoPage *tpage = (TreeviewInfoPage *) ipage;
 	PageInfoDialog *dialog = ipage->dialog;
+	EphyEmbed *embed = dialog->priv->embed;
 	GtkListStore *store = tpage->store;
 	GtkTreeIter iter;
 	GList *links, *l;
@@ -1766,7 +1780,8 @@ links_info_page_fill (InfoPage *ipage)
 	{
 		EmbedPageLink *link = (EmbedPageLink *) l->data;
 
-		should_load = links_is_link_blocked (adblock_manager, 
+		should_load = links_is_link_blocked (adblock_manager,
+						     embed,
 						     link->url);
 
 		gtk_list_store_append (store, &iter);
@@ -1779,8 +1794,8 @@ links_info_page_fill (InfoPage *ipage)
 	}
 	if (ephy_adblock_manager_has_blocker (adblock_manager))
 	{
-		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(store), 
-						      COL_MEDIUM_BLOCKED, 	
+		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE(store),
+						      COL_MEDIUM_BLOCKED,
 						      GTK_SORT_DESCENDING);
 	}
 }
@@ -1885,7 +1900,7 @@ forms_info_page_construct (InfoPage *ipage)
 	gtk_tree_view_column_set_sort_column_id (column, COL_FORM_NAME);
 
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     COL_FORM_METHOD, 
+						     COL_FORM_METHOD,
 						     _("Method"),
 						     renderer,
 						     "text", COL_FORM_METHOD,
@@ -1897,9 +1912,9 @@ forms_info_page_construct (InfoPage *ipage)
 	gtk_tree_view_column_set_sort_column_id (column, COL_FORM_METHOD);
 
 	renderer = gtk_cell_renderer_text_new ();
-	page_info_set_url_renderer_props (renderer); 
+	page_info_set_url_renderer_props (renderer);
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     COL_FORM_ACTION, 
+						     COL_FORM_ACTION,
 						     _("Action"),
 						     renderer,
 						     "text", COL_FORM_ACTION,
@@ -1979,7 +1994,7 @@ enum
 
 static const GtkActionEntry metadata_action_entries[] =
 {
-	{ "CopyMetadata", 
+	{ "CopyMetadata",
 	  GTK_STOCK_COPY,
 	  N_("_Copy"),
 	  NULL,
@@ -2026,7 +2041,7 @@ metadata_info_page_construct (InfoPage *ipage)
 	gtk_tree_view_column_set_sort_column_id (column, COL_META_NAME);
 
 	gtk_tree_view_insert_column_with_attributes (treeview,
-						     COL_META_CONTENT, 
+						     COL_META_CONTENT,
 						     _("Content"),
 						     renderer,
 						     "text", COL_META_CONTENT,
@@ -2051,7 +2066,7 @@ metadata_info_page_construct (InfoPage *ipage)
 	treeview_info_page_construct (ipage);
 }
 
-static gboolean 
+static gboolean
 metadata_add_dc_tag (MetadataInfoPage *page,
 		     EmbedPageMetaTag *tag)
 {
@@ -2122,11 +2137,11 @@ metadata_info_page_fill (InfoPage *ipage)
 	/* Hide the DC widgets if there's no DC metadata */
 	if (!have_dc)
 	{
-		widget = ephy_dialog_get_control (EPHY_DIALOG (dialog), 
+		widget = ephy_dialog_get_control (EPHY_DIALOG (dialog),
 						  properties[PROP_META_DC_BOX].id);
 		gtk_widget_hide (widget);
 
-		widget = ephy_dialog_get_control (EPHY_DIALOG (dialog), 
+		widget = ephy_dialog_get_control (EPHY_DIALOG (dialog),
 						  properties[PROP_META_OTHER_LABEL].id);
 		text = g_strconcat ("<b>", _("Page Metadata"), "</b>", NULL);
 		gtk_label_set_markup (GTK_LABEL (widget), text);
