@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample-extension.c 1376 2006-09-13 19:01:42Z chpe $
+ *  $Id: ephy-sample-extension.c 1634 2007-11-04 01:24:04Z cyrilbois $
  */
 
 #include "config.h"
@@ -82,7 +82,7 @@ impl_detach_window (EphyExtension *ext,
 static void
 impl_attach_tab (EphyExtension *ext,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
 	LOG ("attach_tab");
 }
@@ -90,7 +90,7 @@ impl_attach_tab (EphyExtension *ext,
 static void
 impl_detach_tab (EphyExtension *ext,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
 	LOG ("detach_tab");
 }
